@@ -1,4 +1,4 @@
-/*
+/*                             ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   EightyOne - A simple Sudoku solving game
   Copyright (C) 2006  Tim Teulings
 
@@ -514,7 +514,7 @@ void GameArea::Draw(Lum::OS::DrawInfo* draw,
     }
     else if (!finished->Get() &&
              hintMode->Get() &&
-             i==focusedCell) {
+             i==focusedCell) { // Empty fields with solution hint requested
       std::wstring        text(Lum::Base::NumberToWString(solution.Get(i)));
       Lum::OS::FontExtent extent;
 
@@ -526,7 +526,7 @@ void GameArea::Draw(Lum::OS::DrawInfo* draw,
                        text);
       draw->PopForeground();
     }
-    else {
+    else { // Marked fields
       for (size_t j=0; j<Sudoku::dimension; j++) {
         if (marks[i] & (1 << j)) {
           std::wstring         text(Lum::Base::NumberToWString(j+1));
@@ -777,9 +777,8 @@ void GameArea::SetFocusedCellMarks(size_t value)
   game.Set(focusedCell,Sudoku::empty);
   marks[focusedCell]=value;
 
-  Redraw();
-
   focusChangedAction->Trigger();
+  Redraw();
 }
 
 void GameArea::SetFocusedCellValue(size_t value)
@@ -790,10 +789,11 @@ void GameArea::SetFocusedCellValue(size_t value)
   game.Set(focusedCell,value);
   marks[focusedCell]=0;
 
+  SetFinished(game==solution);
+  focusChangedAction->Trigger();
+
   Redraw();
 
-  focusChangedAction->Trigger();
-  SetFinished(game==solution);
 }
 
 void GameArea::MarkEmpty()
