@@ -17,9 +17,6 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <iostream>
-#include <vector>
-
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
@@ -327,11 +324,6 @@ public:
 
   void UpdateKeypad()
   {
-    if (lock) {
-      return;
-    }
-
-    lock=true;
     if (gameArea==NULL ||
         gameArea->GetFinishedModel()->Get() ||
         !gameArea->IsFocusedCellEditable()) {
@@ -343,6 +335,7 @@ public:
       }
 
       if (mark.Valid()) {
+        mark->Set(false);
         mark->Disable();
       }
 
@@ -350,7 +343,6 @@ public:
         clearAction->Disable();
       }
 
-      lock=false;
       return;
     }
 
@@ -401,24 +393,16 @@ public:
         clearAction->Disable();
       }
     }
-
-    lock=false;
   }
 
-  void UpdateCell()
+  void UpdateCellFromKeypad()
   {
-    if (lock) {
-      return;
-    }
-
     if (gameArea->GetFinishedModel()->Get() ||
         !gameArea->IsFocusedCellEditable()) {
       // We ignore possible changes if there is no valid game
       return;
     }
 
-    lock=true;
-
     size_t marks=0;
     for (size_t i=0; i<Sudoku::dimension; i++) {
       if (keypad[i].Valid() && keypad[i]->Get()) {
@@ -426,15 +410,7 @@ public:
       }
     }
 
-    if (marks==1) {
-      mark->Enable();
-    }
-    else {
-      mark->Set(marks>1);
-      mark->Disable();
-    }
-
-    if (mark->Get()) {
+    if (mark->Get() || marks>1) {
       size_t value=0;
 
       for (size_t i=0; i<Sudoku::dimension; i++) {
@@ -447,6 +423,7 @@ public:
     }
     else {
       bool hasValue=false;
+
       for (size_t i=0; i<Sudoku::dimension; i++) {
         if (keypad[i].Valid() && keypad[i]->Get()) {
           gameArea->SetFocusedCellValue(i+1);
@@ -458,8 +435,6 @@ public:
         gameArea->SetFocusedCellValue(Sudoku::empty);
       }
     }
-
-    lock=false;
   }
 
   void ClearCell()
@@ -469,6 +444,12 @@ public:
 
   void SetRiddle()
   {
+    if (gameArea->GetFinishedModel()->Get() ||
+        !gameArea->IsFocusedCellEditable()) {
+      // We ignore possible changes if there is no valid game
+      return;
+    }
+
     gameArea->SetModel(riddle,solution);
   }
 
@@ -509,10 +490,6 @@ public:
       }
       SaveConfig();
     }
-    else if (model==clearAction &&
-             clearAction->IsFinished()) {
-      ClearCell();
-    }
     else if (model==generateAction &&
              generateAction->IsFinished()) {
       if (ShowGenerateDialog(this,generateTask.minimumPoints)) {
@@ -608,20 +585,41 @@ public:
       statAction->Disable();
       UpdateKeypad();
     }
+    else if (model==clearAction &&
+             clearAction->IsFinished()) {
+      if (!lock) {
+        lock=true;
+        ClearCell();
+        UpdateKeypad();
+        lock=false;
+      }
+    }
     else if (model==gameArea->GetFocusChangedAction() &&
              gameArea->GetFocusChangedAction()->IsFinished()) {
-      UpdateKeypad();
+      if (!lock) {
+        lock=true;
+        UpdateKeypad();
+        lock=false;
+      }
     }
     else if (model==mark) {
-      UpdateCell();
-      UpdateKeypad();
+      if (!lock) {
+        lock=true;
+        UpdateCellFromKeypad();
+        UpdateKeypad();
+        lock=false;
+      }
     }
     else {
-      for (size_t i=0; i<Sudoku::dimension; i++) {
-        if (model==keypad[i]) {
-          UpdateCell();
-          UpdateKeypad();
+      if (!lock) {
+        lock=true;
+        for (size_t i=0; i<Sudoku::dimension; i++) {
+          if (model==keypad[i]) {
+            UpdateCellFromKeypad();
+            UpdateKeypad();
+          }
         }
+        lock=false;
       }
     }
 
