@@ -120,7 +120,7 @@ Lum::Object* StatisticsDialog::GetContent()
   grid->SetObject(6,1,GetText(L"7"));
   grid->SetObject(7,1,GetText(L"8"));
   grid->SetObject(8,1,GetText(L"9"));
-  tab->Add(L"Distribution",grid);
+  tab->Add(_(L"POINTS_DISTRIBUTION",L"Distribution"),grid);
 
   label=Lum::Label::Create(true,true);
 
@@ -149,7 +149,7 @@ Lum::Object* StatisticsDialog::GetContent()
                                     Lum::Text::right,
                                     true,false));
 
-  tab->Add(L"Rating",label);
+  tab->Add(_(L"POINTS_RATING",L"Rating"),label);
 
   return tab;
 }
@@ -168,7 +168,7 @@ void StatisticsDialog::Show(Lum::OS::Window* parent,
 
   dialog=new StatisticsDialog(game,riddle,solution);
   dialog->SetParent(parent);
-  dialog->SetTitle(L"Statistics...");
+  dialog->SetTitle(_(L"POINTS_TITLE",L"Statistics"));
 
   if (dialog->Open()) {
     dialog->EventLoop();
