@@ -17,20 +17,26 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
 #include "Sudoku.h"
 
-class StatisticsDialog : public Lum::Dialog
+class StatisticsDialog : public Lum::Dlg::ActionDialog
 {
 private:
   Sudoku game;
+  Sudoku riddle;
+  Sudoku solution;
 
 public:
-  StatisticsDialog(const Sudoku& game);
+  StatisticsDialog(const Sudoku& game, const Sudoku& riddle, const Sudoku& solution);
   ~StatisticsDialog();
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
-  static void Show(Lum::OS::Window* parent, const Sudoku& game);
+  static void Show(Lum::OS::Window* parent,
+                   const Sudoku& game,
+                   const Sudoku& riddle,
+                   const Sudoku& solution);
 };
